@@ -20,8 +20,8 @@ sub note {
     my $work = join '', map { defined($_) ? $_ : '<UNDEF>' } @_;
     chomp $work;
 
-    # hide the real node in anything that looks like a UUID
-    $work =~ s/([-0-9a-z]{23}-)$realnode/${1}XXXXXXXXXXXX/ig
+    # hide the real node anywhere it appears.
+    $work =~ s/$realnode/XXXXXXXXXXXX/ig
         if $realnode;
 
     print '# ', $work, "\n";
